@@ -77,7 +77,11 @@ bool PrivacyList::moveItemUp(int index)
 		}
 		items_[index].setOrder(items_[index-1].order());
 		items_[index-1].setOrder(order);
+#if QT_VERSION >= 0x050D00
+		items_.swapItemsAt(index,index-1);
+#else
 		items_.swap(index,index-1);
+#endif
 		return true;
 	}
 	else {
@@ -95,7 +99,11 @@ bool PrivacyList::moveItemDown(int index)
 		}
 		items_[index].setOrder(items_[index+1].order());
 		items_[index+1].setOrder(order);
+#if QT_VERSION >= 0x050D00
+		items_.swapItemsAt(index,index+1);
+#else
 		items_.swap(index,index+1);
+#endif
 		return true;
 	}
 	else {
